# Cosmos

<p align="left">
  <img src="cosmos_logo.png" width="150">
</p>

## Update
v1.0: July 15, 2025
- Initial Version of __Cosmos__

## Overview

__Cosmos__ is a python package for multi-phenotype deep mutational scanning analysis. Specifically, it is suitable for two sequential protein functional phenotypes, one upstream and one downstream - for example, abundance and acitivity.

## Installation

__Cosmos__ uses [Poetry](https://python-poetry.org/) for environment and dependency management.

To install __Cosmos__, follow these steps:
1. Install Poetry (if not already installed). Please follow the guideline on [Poetry's official documentation](https://python-poetry.org/docs/).
2. Clone the repository.
```{bash}
git clone https://github.com/Coyote-Maestas-Lab/cosmos.git
cd cosmos
```
3. Install and activate the environment.
```{bash}
poetry lock
poetry install
```



